@@ -1,6 +1,6 @@
 package CHI::t::Driver::File;
 BEGIN {
-  $CHI::t::Driver::File::VERSION = '0.55';
+  $CHI::t::Driver::File::VERSION = '0.56';
 }
 use strict;
 use warnings;
@@ -24,7 +24,7 @@ sub new_cache_options {
 {
     package CHI::t::Driver::File::NoTempDriver;
 BEGIN {
-  $CHI::t::Driver::File::NoTempDriver::VERSION = '0.55';
+  $CHI::t::Driver::File::NoTempDriver::VERSION = '0.56';
 }
     use Moose;
     extends 'CHI::Driver::File';
@@ -39,7 +39,7 @@ BEGIN {
 {
     package CHI::t::Driver::File::BadTempDriver;
 BEGIN {
-  $CHI::t::Driver::File::BadTempDriver::VERSION = '0.55';
+  $CHI::t::Driver::File::BadTempDriver::VERSION = '0.56';
 }
     use Moose;
     extends 'CHI::Driver::File';
@@ -112,10 +112,10 @@ sub test_root_dir_does_not_exist : Tests {
 }
 
 sub test_ignore_bad_namespaces : Tests {
-    my $self  = shift;
-    my $cache = $self->new_cleared_cache(
-        root_dir => tempdir( "chi-driver-file-XXXX", TMPDIR => 1, CLEANUP => 1 )
-    );
+    my $self = shift;
+    my $cache =
+      $self->new_cleared_cache( root_dir =>
+          tempdir( "chi-driver-file-XXXX", TMPDIR => 1, CLEANUP => 1 ) );
 
     foreach my $dir ( ".etc", "+2eetd", 'a@b', 'a+40c', "plain" ) {
         mkpath( join( "/", $cache->root_dir, $dir ) );
